@@ -77,6 +77,16 @@ def punctuation_ratios(text):
     return dict(counts)
 
 
+def analyze(text):
+    return {
+        'average_word_lengths': average_word_lengths(text),
+        'stdev_word_lengths': stdev_word_lengths(text),
+        'average_sentence_lengths': average_sentence_lengths(text),
+        'stdev_sentence_lengths': stdev_sentence_lengths(text),
+    }
+
+
+
 # cosine distance from works of shakespeare, OTHERS in public domain!
 
 def main():
